# macrometa-target-collection

A [Singer](https://singer.io) target that writes data to ([GDN Collections](https://macrometa.com/docs/c8ql/)).

## How to use it

`macrometa_target_collection` works together with any other [Singer Tap] to move data from sources like [Braintree], [Freshdesk] and [Hubspot] to JSONL formatted files.
